import { RawEditorOptions, Editor } from 'tinymce';
import * as i0 from '@angular/core';
import { AfterViewInit, OnChanges, OnDestroy, TemplateRef, EventEmitter, SimpleChange, SimpleChanges, ModuleWithProviders, EnvironmentProviders } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import * as i1 from '@angular/common';

declare class TinymceOptions {
    /** 指定tinymce目录路径，默认：`./assets/tinymce/` */
    baseURL?: string;
    /** 指定tinymce文件名，默认：`tinymce.min.js` */
    fileName?: string;
    /** 默认配置项，对全局 Tinymce 有效 */
    config?: RawEditorOptions;
    /** 延迟加载（单位：毫秒），默认：`0` */
    delay?: number;
}

/**
 * Angular for tinymce, You can modify the global configuration via `provideTinymce`
 */
declare class TinymceComponent implements AfterViewInit, OnChanges, OnDestroy, ControlValueAccessor {
    private defConfig;
    private lazySrv;
    private ngZone;
    private doc;
    private cd;
    private _instance?;
    private value;
    load: boolean;
    id: string;
    private onChange;
    private onTouched;
    config?: RawEditorOptions | null;
    placeholder: string;
    inline: boolean;
    set disabled(value: boolean);
    private _disabled;
    _loading: string | null;
    _loadingTpl: TemplateRef<any> | null;
    set loading(value: string | TemplateRef<any>);
    /** 延迟初始化 */
    delay: number;
    readonly ready: EventEmitter<Editor>;
    get instance(): Editor | undefined | null;
    private _getWin;
    private initDelay;
    private init;
    private destroy;
    private setDisabled;
    ngAfterViewInit(): void;
    ngOnChanges(changes: {
        [P in keyof this]?: SimpleChange;
    } & SimpleChanges): void;
    ngOnDestroy(): void;
    writeValue(value: string): void;
    registerOnChange(fn: (_: any) => {}): void;
    registerOnTouched(fn: () => {}): void;
    setDisabledState(isDisabled: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TinymceComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TinymceComponent, "tinymce", ["tinymce"], { "config": { "alias": "config"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "inline": { "alias": "inline"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "delay": { "alias": "delay"; "required": false; }; }, { "ready": "ready"; }, never, ["*"], true, never>;
    static ngAcceptInputType_inline: unknown;
    static ngAcceptInputType_disabled: unknown;
    static ngAcceptInputType_delay: unknown;
}

declare class NgxTinymceModule {
    static forRoot(options: TinymceOptions): ModuleWithProviders<NgxTinymceModule>;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxTinymceModule, never>;
    static ɵmod: i0.ɵɵNgModuleDeclaration<NgxTinymceModule, never, [typeof i1.CommonModule, typeof TinymceComponent], [typeof TinymceComponent]>;
    static ɵinj: i0.ɵɵInjectorDeclaration<NgxTinymceModule>;
}

/**
 * Sets up providers necessary to config for the Tinymce.
 * @example
 * bootstrapApplication(AppComponent, {
 *   providers: [provideTinymce({baseURL: '//cdn.tiny.cloud/1/no-api-key/tinymce/6/'})]
 * });
 */
declare function provideTinymce(options: TinymceOptions): EnvironmentProviders;

export { NgxTinymceModule, TinymceComponent, TinymceOptions, provideTinymce };
